@@ -1,12 +1,13 @@
 /**************************************************************************
  *  Kchmviewer for Maemo5 - a CHM file viewer with broad language support *
+ *  Port of KChmViewer ( www.kchmviewer.net ) to mobile platforms         *
  *  Copyright (C) 2009-2010 Max Kiva , max.kiva@gmail.com                 *
  *                                                                        *
  *  This program is free software: you can redistribute it and/or modify  *
  *  it under the terms of the GNU General Public License as published by  *
  *  the Free Software Foundation, either version 3 of the License, or     *
  *  (at your option) any later version.                                   *
- *															                                  	      *
+ *                                                                        *
  *  This program is distributed in the hope that it will be useful,       *
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of        *
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
@@ -15,6 +16,7 @@
  *  You should have received a copy of the GNU General Public License     *
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  **************************************************************************/
+
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
@@ -25,6 +27,8 @@ class ToolBarWidget;
 class ContentsWidget;
 class QPushButton;
 class QKeyEvent;
+class QMenu;
+class QAction;
 
 class MainWindow: public QMainWindow
 {
@@ -36,6 +40,8 @@ public:
 
 public:
     // these calls are made when the toolbar gets clicked
+    void doBookmarks();
+    void doRecentDocs();
     void doFullScreenOn();
     void doZoomIn();
     void doZoomOut();
@@ -44,7 +50,8 @@ public:
 
 public slots:
     void minimizeApplication();
-    void pickedContent();
+    void pickedContent( int page );
+    void doFind();
     void doFullScreenOff();
     void doNextPage();
     void doPrevPage();
@@ -55,6 +62,9 @@ public slots:
 protected:
     void keyPressEvent(QKeyEvent* event);
       
+private slots:
+    void bookmarkCurrentPage();
+    void findInCurrentPage();
 
 private:
     void openFile( const QString& fileName );
@@ -73,6 +83,10 @@ private:
     QPushButton* fullScreenOff_;
     QPushButton* nextPage_;
     QPushButton* prevPage_;  
+
+
+    QAction* bookmarkPage_;
+    QAction* findInPage_;
    
 
     bool fullScreenMode_;
