@@ -1,12 +1,13 @@
 /**************************************************************************
  *  Kchmviewer for Maemo5 - a CHM file viewer with broad language support *
+ *  Port of KChmViewer ( www.kchmviewer.net ) to mobile platforms         *
  *  Copyright (C) 2009-2010 Max Kiva , max.kiva@gmail.com                 *
  *                                                                        *
  *  This program is free software: you can redistribute it and/or modify  *
  *  it under the terms of the GNU General Public License as published by  *
  *  the Free Software Foundation, either version 3 of the License, or     *
  *  (at your option) any later version.                                   *
- *															                                  	      *
+ *                                                                        *
  *  This program is distributed in the hope that it will be useful,       *
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of        *
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
@@ -43,7 +44,10 @@ class ToolBarWidget : public QWidget
 
   private slots:
     void clickedOpenFile(); 
+    void clickedRecentDocs(); 
     void clickedContents(); 
+    void clickedBookmarks(); 
+    void clickedFind(); 
     void clickedZoomOut();
     void clickedZoomIn();
     void clickedNextPage();
@@ -52,10 +56,10 @@ class ToolBarWidget : public QWidget
 
   private:
 
-    enum { BUTTON_NUM=7 };
+    enum { EOpen, ERecentDocs, EContents, EBookmarks, EFind, EPrev, ENext, EZoomIn, EZoomOut, EFullScreen, ENumButtons };
     
     QHBoxLayout* layout_;
-    QPushButton* btns_[ BUTTON_NUM ];
+    QPushButton* btns_[ ENumButtons ];
     
 };
 
